==> aliyun-java-sdk-ecs-4.21.0-sources.jar: com/aliyuncs/ecs/transform/v20140526/PurchaseReservedInstancesOfferingResponseUnmarshaller.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.ecs.transform.v20140526;

import java.util.ArrayList;
import java.util.List;

import com.aliyuncs.ecs.model.v20140526.PurchaseReservedInstancesOfferingResponse;
import com.aliyuncs.transform.UnmarshallerContext;


public class PurchaseReservedInstancesOfferingResponseUnmarshaller {

	public static PurchaseReservedInstancesOfferingResponse unmarshall(PurchaseReservedInstancesOfferingResponse purchaseReservedInstancesOfferingResponse, UnmarshallerContext _ctx) {
		
		purchaseReservedInstancesOfferingResponse.setRequestId(_ctx.stringValue("PurchaseReservedInstancesOfferingResponse.RequestId"));

		List<String> reservedInstanceIdSets = new ArrayList<String>();
		for (int i = 0; i < _ctx.lengthValue("PurchaseReservedInstancesOfferingResponse.ReservedInstanceIdSets.Length"); i++) {
			reservedInstanceIdSets.add(_ctx.stringValue("PurchaseReservedInstancesOfferingResponse.ReservedInstanceIdSets["+ i +"]"));
		}
		purchaseReservedInstancesOfferingResponse.setReservedInstanceIdSets(reservedInstanceIdSets);
	 
	 	return purchaseReservedInstancesOfferingResponse;
	}
}

==> aliyun-java-sdk-ecs-5.11.17-sources.jar: com/aliyuncs/ecs/transform/v20140526/PurchaseReservedInstancesOfferingResponseUnmarshaller.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.ecs.transform.v20140526;

import java.util.ArrayList;
import java.util.List;

import com.aliyuncs.ecs.model.v20140526.PurchaseReservedInstancesOfferingResponse;
import com.aliyuncs.transform.UnmarshallerContext;


public class PurchaseReservedInstancesOfferingResponseUnmarshaller {

	public static PurchaseReservedInstancesOfferingResponse unmarshall(PurchaseReservedInstancesOfferingResponse purchaseReservedInstancesOfferingResponse, UnmarshallerContext _ctx) {
		
		purchaseReservedInstancesOfferingResponse.setRequestId(_ctx.stringValue("PurchaseReservedInstancesOfferingResponse.RequestId"));
		purchaseReservedInstancesOfferingResponse.setOrderId(_ctx.stringValue("PurchaseReservedInstancesOfferingResponse.OrderId"));

		List<String> reservedInstanceIdSets = new ArrayList<String>();
		for (int i = 0; i < _ctx.lengthValue("PurchaseReservedInstancesOfferingResponse.ReservedInstanceIdSets.Length"); i++) {
			reservedInstanceIdSets.add(_ctx.stringValue("PurchaseReservedInstancesOfferingResponse.ReservedInstanceIdSets["+ i +"]"));
		}
		purchaseReservedInstancesOfferingResponse.setReservedInstanceIdSets(reservedInstanceIdSets);
	 
	 	return purchaseReservedInstancesOfferingResponse;
	}
}
